# xwformats Examples

This directory contains usage examples for xwformats.

## Examples

Examples will be added here demonstrating:
- Format serialization
- Format conversion
- Enterprise format usage (Protobuf, Avro, Parquet, etc.)
- Scientific format usage (HDF5, NetCDF, Zarr, etc.)
- Database format usage (LMDB, LevelDB, GraphDB, etc.)

